@@ -7,7 +7,6 @@
  *  Arnaud Martin, Antoine Pitrou, Philippe Rivière, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribué sous licence GNU/GPL.     *
- *  Pour plus de détails voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
 /**
@@ -166,6 +165,7 @@ function aide_data(?string $groupe = null): array {
 			}
 			$menu[$groupe] = [
 				'titre' => _T('aide:' . $groupe),
+				'slug' => $groupe,
 				'intro' => aide_contenu($groupe, '_intro'),
 				'entrees' => [],
 			];
@@ -173,6 +173,7 @@ function aide_data(?string $groupe = null): array {
 				$menu[$groupe]['entrees'][] = [
 					'titre' => _T('aide:' . $groupe . '_' . $entree),
 					'groupe' => $menu[$groupe]['titre'],
+					'slug' => $menu[$groupe]['slug'] . '-' . $entree,
 					'texte' => aide_contenu($groupe, $entree),
 				];
 			}
@@ -226,3 +227,34 @@ function aide_langues($lang = null): array {
 	}
 	return $langues[$lang];
 }
+
+/** Gérer le raccourcis `<aide:code>...</aide:code>` */
+function aide_pre_echappe_html_propre($flux) {
+	if (
+		str_contains($flux, '<')
+		&& str_contains($flux, '<aide:code>')
+	) {
+		$regexp = '#' . preg_quote('<aide:code>') . '(.*)' . preg_quote('</aide:code>') . '#Uims';
+		while (preg_match($regexp, $flux, $matches)) {
+			$code = trim($matches[1]);
+			$flux = str_replace(
+				$matches[0],
+				<<<HTML
+				<div class="aide_code">
+				<div class="aide_code_source">
+				````
+				$code
+				````
+				</div>
+				<div class="aide_code_result">
+				<p></p>
+				$code
+				</div>
+				</div>
+				HTML,
+				$flux,
+			);
+		}
+	}
+	return $flux;
+}
