@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/aide-aide?lang_cible=en
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// R
 	'raccourcis' => 'Typographical shortcuts',
@@ -20,5 +16,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'raccourcis_note' => 'Footnotes',
 	'raccourcis_resume' => 'In short',
 	'raccourcis_simple' => 'Simple formatting',
-	'raccourcis_tableau' => 'Tables'
-);
+	'raccourcis_tableau' => 'Tables',
+];
