@@ -1,14 +1,11 @@
 <?php
 // This is a SPIP language file  --  Ceci est un fichier langue de SPIP
 // Fichier source, a modifier dans https://git.spip.net/spip/bigup.git
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
 
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// B
 	'bigup_description' => 'Téléverser les documents par glisser-déposer',
 	'bigup_nom' => 'Big Upload',
-	'bigup_slogan' => 'Téléverser des fichiers, quelque soit leur taille'
-);
+	'bigup_slogan' => 'Téléverser des fichiers, quelque soit leur taille',
+];
