@@ -3,14 +3,10 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/bigup-paquet-xml-bigup?lang_cible=pt_br
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// B
-	'bigup_description' => '', # MODIF
+	'bigup_description' => 'Transferir documentos usando arrastar-e-soltar',
 	'bigup_nom' => 'Big Upload',
-	'bigup_slogan' => 'Transferir arquivos de qualquer tamanho'
-);
+	'bigup_slogan' => 'Transferir arquivos de qualquer tamanho',
+];
