@@ -3,15 +3,11 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-compagnon?lang_cible=br
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// C
 	'compagnon_description' => 'An ambrouger a ginnig sikour d’an implijerien
 		da vare ar c’hentañ weladenn el lec’h prevez SPIP.',
 	'compagnon_nom' => 'Ambrouger',
-	'compagnon_slogan' => 'Ambrouger evit kregiñ gant SPIP'
-);
+	'compagnon_slogan' => 'Ambrouger evit kregiñ gant SPIP',
+];
