@@ -3,14 +3,10 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-compagnon?lang_cible=fa
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// C
 	'compagnon_description' => 'همراه به كاربران در جريان نخستين ازديدشان از قسمت خصوصي اسپيپ كمك ارايه مي‌كند. ',
 	'compagnon_nom' => 'همراه ',
-	'compagnon_slogan' => 'همراه اول با اسپيپ نيست'
-);
+	'compagnon_slogan' => 'همراه اول با اسپيپ نيست',
+];
