@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/compresseur?lang_cible=br
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// E
 	'explication_url_statique_ressources' => 'Un URL evit kas fichennoù stadegouriezh (skeudennoù, JS...) hep cookie. Peurliesañ un iz-domani all o bukañ ivez war al lec’hienn.',
@@ -25,5 +21,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	// T
 	'texte_compacter_avertissement' => 'Diwallit da chom hep gweredekaat an dibarzhioù-mañ e-keit hag emeur o sevel ho lec’hienn : n’hall ket an elfennoù stummaet bezañ lennet ken war-lerc’h.',
 	'texte_compacter_script_css' => 'Gallout a ra SPIP stummaat ar skriptoù javascript hag ar follennoù-stil CSS, evit enrollañ anezho er restroù statek ;  buanoc’h e teu al lec’hienn war wel.',
-	'titre_compacter_script_css' => 'Stummaat ar skriptoù ha CSS'
-);
+	'titre_compacter_script_css' => 'Stummaat ar skriptoù ha CSS',
+];
