@@ -1,11 +1,8 @@
 <?php
 // This is a SPIP language file  --  Ceci est un fichier langue de SPIP
 // Fichier source, a modifier dans https://git.spip.net/spip/compresseur.git
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
 
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// E
 	'explication_url_statique_ressources' => 'Une URL qui permet de servir les fichiers statiques (images, JS…) sans cookie. Généralement un sous-domaine alternatif qui pointe aussi sur le site.',
@@ -23,5 +20,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	// T
 	'texte_compacter_avertissement' => 'Attention à ne pas activer ces options durant le développement de votre site : les éléments compactés perdent toute lisibilité.',
 	'texte_compacter_script_css' => 'SPIP peut compacter les scripts javascript et les feuilles de style CSS, pour les enregistrer dans des fichiers statiques ; cela accélère l’affichage du site.',
-	'titre_compacter_script_css' => 'Compactage des scripts et CSS'
-);
+	'titre_compacter_script_css' => 'Compactage des scripts et CSS',
+];
