@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-compresseur?lang_cible=ja
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// C
 	'compresseur_description' => '<code>ecrire/</code>と言うhtmlページや公開サイトのヘッダーにあるCSSとjavascriptの圧縮',
-	'compresseur_slogan' => 'CSSとjavascriptの圧縮'
-);
+	'compresseur_slogan' => 'CSSとjavascriptの圧縮',
+];
