@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-compresseur?lang_cible=pt_br
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// C
 	'compresseur_description' => 'Compressão dos css e javascript nos cabeçalhos das páginas html de <code>ecrire/</code> e/ou do site público',
-	'compresseur_slogan' => 'Compressão dos css e javascript'
-);
+	'compresseur_slogan' => 'Compressão dos css e javascript',
+];
