@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-images?lang_cible=uk
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// I
 	'images_description' => 'Фільтри для обробки зображень і роботи з кольорами',
-	'images_slogan' => 'Фільтри для обробки зображень і роботи з кольорами'
-);
+	'images_slogan' => 'Фільтри для обробки зображень і роботи з кольорами',
+];
