@@ -166,7 +166,8 @@ function formulaires_editer_logo_verifier_dist($objet, $id_objet, $retour = '',
 	// verifier les extensions
 	$sources = formulaire_editer_logo_get_sources();
 	include_spip('action/editer_logo');
-	$extensions_possibles = $GLOBALS['formats_logos'];
+	include_spip('inc/filtres_images_lib_mini');
+	$extensions_possibles = _image_extensions_logos(['objet' => $objet, 'id_objet' => $id_objet]);
 	if (in_array('jpg', $extensions_possibles)) {
 		$extensions_possibles[] = 'jpeg';
 	}
