@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=is
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// F
 	'forum_acces_refuse' => 'Þú hefur ekki lengur aðgang að þessari umræðu.',
@@ -25,5 +21,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	// I
 	'icone_poster_message' => 'Senda skilaboð',
 	'icone_supprimer_message' => 'Eyða þessum skilaboðum',
-	'icone_valider_message' => 'Staðfesta skilaboðin'
-);
+	'icone_valider_message' => 'Staðfesta skilaboðin',
+];
