@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-forum?lang_cible=ru
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// F
 	'forum_description' => 'Форумы и комментарии в SPIP',
-	'forum_slogan' => 'Управление форумами и комментариями'
-);
+	'forum_slogan' => 'Управление форумами и комментариями',
+];
