@@ -7,9 +7,10 @@
  *  Arnaud Martin, Antoine Pitrou, Philippe Rivière, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribué sous licence GNU/GPL.     *
- *  Pour plus de détails voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
+use Spip\Compilateur\Noeud\Boucle;
+
 /**
  * Gestion de l'itérateur CONDITION
  *
@@ -42,19 +43,3 @@ function iterateur_CONDITION_dist($b) {
 
 	return $b;
 }
-
-/**
- * Iterateur CONDITION pour itérer sur des données
- *
- * La boucle condition n'a toujours qu'un seul élément.
- */
-class IterateurCONDITION extends IterateurData {
-	/**
-	 * Obtenir les données de la boucle CONDITION
-	 *
-	 * @param array $command
-	 **/
-	protected function select($command) {
-		$this->tableau = [0 => 1];
-	}
-}
