@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/ecrire_?lang_cible=bg
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// A
 	'activer_plugin' => 'Активирайте плъгина',
@@ -23,7 +19,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'avis_connexion_echec_3' => '<b>ВНИМАНИЕ!</b> За достъп до голяма част от сървърите е необходимо да се изпрати <b>заявка</b> за активиране достъпа до базите данни SQL, преди използването им. Ако не успеете да се свържете, проверете дали сте изпратили заявката.', # MODIF
 	'avis_connexion_ldap_echec_1' => 'Връзката с LDAP сървъра пропадна.',
 	'avis_connexion_ldap_echec_2' => 'Моля, върнете се на предишната страница, за за проверите подадената информация.',
-	'avis_connexion_ldap_echec_3' => 'Без използване на LDAP-поддръжка за вписване на потребители.',
+	'avis_connexion_ldap_echec_3' => 'Без използване на LDAP-поддръжка за вписване на потребители.', # MODIF
 	'avis_deplacement_rubrique' => 'Предупреждение! Рубриката съдържа @contient_breves@ новина@scb@: ако желаете да я преместите, отметнете в полето за потвърждение. ',
 	'avis_erreur_connexion_mysql' => 'Грешка при свързване с SQL',
 	'avis_espace_interdit' => '<b>Забранена област</b><p>СПИП е вече инсталиран.', # MODIF
@@ -44,10 +40,10 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'bouton_envoyer_message' => 'Последно съобщение: изпращане',
 	'bouton_modifier' => 'Промяна',
 	'bouton_radio_afficher' => 'Показване',
-	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Добяване към списъка на текущо свързаните редактори',
+	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Добяване към списъка на текущо свързаните редактори', # MODIF
 	'bouton_radio_envoi_annonces_adresse' => 'Изпращане на съобщения до следния адрес:',
 	'bouton_radio_envoi_liste_nouveautes' => 'Изпращане на списък с новини',
-	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Изключване от списъка на текущо свързаните редактори',
+	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Изключване от списъка на текущо свързаните редактори', # MODIF
 	'bouton_radio_non_envoi_annonces_editoriales' => 'Отказ от изпращане на редакторски съобщения',
 	'bouton_redirection' => 'ПРЕНАСОЧВАНЕ',
 	'bouton_relancer_installation' => 'Подновяване на инсталацията',
@@ -57,7 +53,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'bouton_vider_cache' => 'Изпразване на кеш-паметта',
 
 	// C
-	'cache_modifiable_webmestre' => 'Параметърът може да бъде променен от уеб-администратора. ',
+	'cache_modifiable_webmestre' => 'Параметърът може да бъде променен от уеб-администратора. ', # MODIF
 	'calendrier_synchro' => 'Ако инсталирате приложение за дневник, съвместимо с <b>iCal</b>, ще можете да го синхронизирате с информацията от сайта.',
 
 	// D
@@ -75,7 +71,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'entree_cle_pgp' => 'PGP ключ',
 	'entree_contenu_rubrique' => '(Кратко съдържание на рубриката.)',
 	'entree_identifiants_connexion' => 'Идентефикатори за свързване',
-	'entree_informations_connexion_ldap' => 'Моля, попълнете бланката с информацията за LDAP връзка. Тази информация ще получите от системния или мрежовия администратор.',
+	'entree_informations_connexion_ldap' => 'Моля, попълнете бланката с информацията за LDAP връзка. Тази информация ще получите от системния или мрежовия администратор.', # MODIF
 	'entree_infos_perso' => 'Кой си ти?',
 	'entree_interieur_rubrique' => 'В рубриката:',
 	'entree_liens_sites' => '<b>Хипертекстова препратка</b> (препратка, сайт за посещаване и т.н.)',
@@ -138,12 +134,12 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_1_article' => '1 статия',
 	'info_activer_cookie' => 'Възможност за активиране на <b>cookie администриране</b>, което позволява
  улеснено превключване между публичния сайт и личната зона.',
-	'info_administrateur' => 'Администратор',
-	'info_administrateur_1' => 'Администратор',
+	'info_administrateur' => 'Администратор', # MODIF
+	'info_administrateur_1' => 'Администратор', # MODIF
 	'info_administrateur_2' => 'на сайта (<i>внимавайте</i>)',
-	'info_administrateur_site_01' => 'Ако сте администратор на сайта, моля',
+	'info_administrateur_site_01' => 'Ако сте администратор на сайта, моля', # MODIF
 	'info_administrateur_site_02' => 'посещаване на препратката',
-	'info_administrateurs' => 'Администратори',
+	'info_administrateurs' => 'Администратори', # MODIF
 	'info_administrer_rubrique' => 'Вие можете да управлявате рубриката',
 	'info_adresse' => 'към адрес:',
 	'info_adresse_url' => 'Публичен URL на сайта ',
@@ -173,7 +169,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_chapeau' => 'Преглед',
 	'info_chapeau_2' => 'Въведение:',
 	'info_chemin_acces_1' => 'Опции: <b>Път за достъп до директорията</b>',
-	'info_chemin_acces_2' => 'От сега нататък Вие трябва да определяте пътя за достъп до данните в директорията. Тази информация дава възможност за преглед на потребителските профили, съхранени там.',
+	'info_chemin_acces_2' => 'От сега нататък Вие трябва да определяте пътя за достъп до данните в директорията. Тази информация дава възможност за преглед на потребителските профили, съхранени там.', # MODIF
 	'info_chemin_acces_annuaire' => 'Опции: <b>Път за достъп</b>',
 	'info_choix_base' => 'Трета стъпка:',
 	'info_classement_1' => '<sup>st</sup> от общо @liste@',
@@ -214,17 +210,14 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
   на редактори, например.
 ', # MODIF
 	'info_fichiers_authent' => 'Файл за удостоверяване автентичността: .htpasswd',
-	'info_forums_abo_invites' => 'Сайтът Ви съдържа форуми посредством предварителен абонамент; посетителите могат да се регистират за тях през публичния сайт.',
+	'info_forums_abo_invites' => 'Сайтът Ви съдържа форуми посредством предварителен абонамент; посетителите могат да се регистират за тях през публичния сайт.', # MODIF
 	'info_gauche_admin_tech' => '<b>Само администратори имат достъп до тази страница.</b><p> Тя осигурява достъп до различни
  технически задачи за поддръжка. Някои от тях позволяват специфичен процес на
-идентификация и изискват FTP достъп до сайта.', # MODIF
-	'info_gauche_admin_vider' => '<b>Само администратори имат достъп до тази страница.</b><p> Тя осигурява достъп доразлични
-технически задачи за поддръжка. Някои от тях позволяват специфичен процес на
 идентификация и изискват FTP достъп до сайта.', # MODIF
 	'info_gauche_auteurs' => 'Тук ще намерите всички автори на сайта.
- Статусът на всеки от тях е обозначен с цвета на неговата икона (редактор - жълта; администратор - зелена).',
+ Статусът на всеки от тях е обозначен с цвета на неговата икона (редактор - жълта; администратор - зелена).', # MODIF
 	'info_gauche_auteurs_exterieurs' => 'Външни автори, без достъп до сайта, са обозначени със синя икона; изтритите автори - с кошче за боклук.', # MODIF
-	'info_gauche_messagerie' => 'Изпращането на съобщения позволява да се обменя информация между редакторите, да се съхраняват бележки (за лично ползване) или да се публикуват обяви в началната страница на личната зона (ако сте администратор).',
+	'info_gauche_messagerie' => 'Изпращането на съобщения позволява да се обменя информация между редакторите, да се съхраняват бележки (за лично ползване) или да се публикуват обяви в началната страница на личната зона (ако сте администратор).', # MODIF
 	'info_gauche_statistiques_referers' => 'Тази страница показва списък с <i>препратки към сайтове</i>: т.е. сайтовете, съдържащи връзка към Вашия сайт, само за вчера и днес: този списък се акуализира на всеки 24 часа.',
 	'info_gauche_visiteurs_enregistres' => 'Тук ще намерите посетителите, регистрирани
  в публичната зона на сайта (форумите са с предварително записване).',
@@ -238,14 +231,14 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_image_process2' => '<b>N.B.</b> <i>Ако не можете да видите никакво изображение, следователно сървърът Ви не е конфигуриран да използва такива инструменти. Ако искате да ползвате това свойство, трябва да се свържете с доставчика си и да поискате да ви инсталират разширения от типа "GD" или "Imagick"</i>', # MODIF
 	'info_images_auto' => 'Автоматично изчислени изображения',
 	'info_informations_personnelles' => 'Стъпка пет: <b>Лични данни</b>',
-	'info_inscription_automatique' => 'Автоматична регистрация на нови редактори',
+	'info_inscription_automatique' => 'Автоматична регистрация на нови редактори', # MODIF
 	'info_jeu_caractere' => 'Кодировка на сайта',
 	'info_jours' => 'дни',
 	'info_laisser_champs_vides' => 'оставите празни полетата)',
 	'info_langues' => 'Езици на сайта',
 	'info_ldap_ok' => 'Инсталирана е аутентификация за LDAP.',
 	'info_lien_hypertexte' => 'Хипертекстова препратка:',
-	'info_liste_redacteurs_connectes' => 'Списък на свързаните редактори',
+	'info_liste_redacteurs_connectes' => 'Списък на свързаните редактори', # MODIF
 	'info_login_existant' => 'Потребителското име вече съществува.',
 	'info_login_trop_court' => 'Потребителското име е твърде кратко.',
 	'info_maximum' => 'максимум:',
@@ -265,7 +258,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_moyenne' => 'средно:',
 	'info_multi_cet_article' => 'Език на статията:',
 	'info_multi_langues_choisies' => 'Изберете по-долу езиците, които желаете да са активни за редакторите на сайта.
-  Езиците, които вече са използвани в сайта (в началото на списъка) не могат да бъдат деактивирани.',
+  Езиците, които вече са използвани в сайта (в началото на списъка) не могат да бъдат деактивирани.', # MODIF
 	'info_multi_secteurs' => ' ... само за рубрики, намиращи се в схемата?',
 	'info_nom' => 'Име',
 	'info_nom_destinataire' => 'Име на получателя',
@@ -284,8 +277,8 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_nouvelle_traduction' => 'Нов превод:',
 	'info_numero_article' => 'НОМЕР НА СТАТИЯТА:',
 	'info_obligatoire_02' => '[Задължително]', # MODIF
-	'info_option_accepter_visiteurs' => 'Позволяване регистрацията на посетители от публичния сайт',
-	'info_option_ne_pas_accepter_visiteurs' => 'Отказ за регистрация на посетител',
+	'info_option_accepter_visiteurs' => 'Позволяване регистрацията на посетители от публичния сайт', # MODIF
+	'info_option_ne_pas_accepter_visiteurs' => 'Отказ за регистрация на посетител', # MODIF
 	'info_options_avancees' => 'ПОДРОБНИ ОПЦИИ',
 	'info_ou' => 'или ...',
 	'info_page_interdite' => 'Забранена страница',
@@ -306,7 +299,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_ps' => 'П.С. ',
 	'info_publier' => 'публикуване',
 	'info_publies' => 'Вашите публикувани статии',
-	'info_question_accepter_visiteurs' => 'Ако шаблоните на сайта Ви позволяват посетителите да се регистират без да влизат в личната зона, активирайте следната опция:',
+	'info_question_accepter_visiteurs' => 'Ако шаблоните на сайта Ви позволяват посетителите да се регистират без да влизат в личната зона, активирайте следната опция:', # MODIF
 	'info_question_inscription_nouveaux_redacteurs' => 'Позволявате ли регистрацията на нови редактори от
   публикувания сайт. Ако сте съгласни, посетителите трябва да се
   регистрират през автоматичната форма, за да имат достъп до личната зона и
@@ -329,7 +322,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_refuses' => 'Вашите отхвърлени статии',
 	'info_reglage_ldap' => 'Опции: <b>Приспособяване на вписването чрез LDAP</b>',
 	'info_renvoi_article' => '<b>Пренасочване.</b> Статията се отнася към страница:',
-	'info_reserve_admin' => 'Този адрес може да се променя само от администратори.',
+	'info_reserve_admin' => 'Този адрес може да се променя само от администратори.', # MODIF
 	'info_restreindre_rubrique' => 'Забрана за управление на рубриката:',
 	'info_resultat_recherche' => 'Намерени резултати:',
 	'info_rubriques' => 'Рубрики',
@@ -348,13 +341,13 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_sites_proxy' => 'Използване на прокси',
 	'info_sites_trouves' => 'Намерени сайтове',
 	'info_sous_titre' => 'Подзаглавие:',
-	'info_statut_administrateur' => 'Администратор',
+	'info_statut_administrateur' => 'Администратор', # MODIF
 	'info_statut_auteur' => 'Статус на автора:', # MODIF
 	'info_statut_auteur_a_confirmer' => 'Регистрация, предстояща за потвърждение',
 	'info_statut_auteur_autre' => 'Друг статус:',
 	'info_statut_redacteur' => 'Редактор',
-	'info_statut_utilisateurs_1' => 'Статус "по подразбиране" на вписаните потребители',
-	'info_statut_utilisateurs_2' => 'Изберете статус за хората, вписани в LDAP-директорията при свързването им за първи път. По-късно ще можете да променяте тази характеристика за всеки автор по отделно.',
+	'info_statut_utilisateurs_1' => 'Статус "по подразбиране" на вписаните потребители', # MODIF
+	'info_statut_utilisateurs_2' => 'Изберете статус за хората, вписани в LDAP-директорията при свързването им за първи път. По-късно ще можете да променяте тази характеристика за всеки автор по отделно.', # MODIF
 	'info_suivi_activite' => 'Дейности на редакторите',
 	'info_surtitre' => 'Челно заглавие:',
 	'info_syndication_integrale_1' => 'Сайтът Ви предлага файлове за обединение (вж <a href="@url@">@titre@</a>).',
@@ -399,10 +392,10 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'intem_redacteur' => 'редактор',
 	'item_accepter_inscriptions' => 'Позволяване на регистрации',
 	'item_activer_messages_avertissement' => 'Активиране на предупредителни съобщения',
-	'item_administrateur_2' => 'администратор',
+	'item_administrateur_2' => 'администратор', # MODIF
 	'item_afficher_calendrier' => 'Показване в календара',
 	'item_autoriser_syndication_integrale' => 'Включване на цели статии във файловете за обединяване',
-	'item_choix_administrateurs' => 'администратори',
+	'item_choix_administrateurs' => 'администратори', # MODIF
 	'item_choix_generation_miniature' => 'Автоматично генериране на умалени образи.',
 	'item_choix_non_generation_miniature' => 'Без генериране на умалени образи.',
 	'item_choix_redacteurs' => 'редактори',
@@ -483,15 +476,15 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'texte_acces_ldap_anonyme_1' => 'Някои LDAP-сървъри не позволяват анонимен достъп. В такива случаи, за да можете да правите справка в директорията, трябва да използвате началното си потребителско име за достъп. Въпреки това, в повечето случаи можете да оставяте следните полета празни. ',
 	'texte_admin_effacer_01' => 'Тази команда изтрива <i>цялото</i> съдържание в базата данни,
 включително <i>всички</i> параметри за достъп за редактори и администратори. След нейното изпълнение, трябва
-да се преинсталира СПИП, за да се създаде нова база данни и първи администраторски достъп.',
+да се преинсталира СПИП, за да се създаде нова база данни и първи администраторски достъп.', # MODIF
 	'texte_adresse_annuaire_1' => '( Ако директорията Ви е инсталирана на същата машина, на която и Интернет сайта, вероятно е «localhost».)',
 	'texte_ajout_auteur' => 'Следният автор бе добавен към статията:',
-	'texte_annuaire_ldap_1' => 'Ако разполагате с достъп до (LDAP) директория, можете да я използвате, за да вписвате автоматично потребители в СПИП.',
+	'texte_annuaire_ldap_1' => 'Ако разполагате с достъп до (LDAP) директория, можете да я използвате, за да вписвате автоматично потребители в СПИП.', # MODIF
 	'texte_article_statut' => 'Статията е:',
 	'texte_article_virtuel' => 'Виртуална статия',
 	'texte_article_virtuel_reference' => '<b>Виртуална статия:</b> свързана статия на Вашия СПИП сайт, която се пренасочва към друг URL адрес. За да премахнете пренасочването, изтрийте горепосочения URL.',
 	'texte_aucun_resultat_auteur' => 'Няма намерен разултат за @cherche_auteur@.',
-	'texte_auteur_messagerie' => 'Сайт може продължително да следи списъка от свързани редактори, което позволява изпращането та съобщения в реално време (ако съобщението е забранено по-горе, тогава целият списък от редактори е забранен). Вие можете да решите да не се появявате в този списък (т.е. да сте невидим за останалите потребители).',
+	'texte_auteur_messagerie' => 'Сайт може продължително да следи списъка от свързани редактори, което позволява изпращането та съобщения в реално време (ако съобщението е забранено по-горе, тогава целият списък от редактори е забранен). Вие можете да решите да не се появявате в този списък (т.е. да сте невидим за останалите потребители).', # MODIF
 	'texte_auteurs' => 'АВТОРИТЕ',
 	'texte_choix_base_1' => 'Изберете база данни:',
 	'texte_choix_base_2' => 'Сървърът SQL съдържа няколко бази данни.',
@@ -603,11 +596,10 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
   с цел да избегнат едновременни промени.
   Тази операция е изключена по начало,
   с цел да не се показват излишни
-  предупредителни съобщения.',
+  предупредителни съобщения.', # MODIF
 	'texte_vide' => 'празно',
 	'texte_vider_cache' => 'Изпразване на кеш-паметта',
 	'titre_admin_tech' => 'Техническа поддръжка',
-	'titre_admin_vider' => 'Техническа поддръжка',
 	'titre_cadre_afficher_article' => 'Показване на статиите:',
 	'titre_cadre_afficher_traductions' => 'Показване статуса на превод на следния език:',
 	'titre_cadre_ajouter_auteur' => 'ДОБАВЯНЕ НА АВТОР:',
@@ -646,5 +638,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'utf8_convert_erreur_orig' => 'Грешка: кодировката на символите @charset@ не се поддържа.',
 
 	// V
-	'version' => 'Версия:'
-);
+	'version' => 'Версия:',
+];
