@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-dist?lang_cible=pt_br
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// D
 	'dist_description' => 'Conjunto de gabaritos distribuído com o SPIP 3.',
-	'dist_slogan' => 'Gabaritos padrão do SPIP 3'
-);
+	'dist_slogan' => 'Gabaritos padrão do SPIP 3',
+];
