@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-mediabox?lang_cible=ar
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// M
 	'mediabox_description' => 'افتراضياً، يتم إضفاء صندوق الفرجة على كل الوصلات الى الصور (لها نوع خاصية يصف mime/type الصورة) إضافة الى الوصلات المزودة بنمط &lt;code&gt;.mediabox&lt;/code&gt;.
@@ -28,5 +24,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 
 يعمل هذا الملحق في الصفحات النموذجية التي تحتوي على علامة <code>#INSERT_HEAD</code>',
 	'mediabox_nom' => 'صندوق الفرجة',
-	'mediabox_slogan' => 'صندوق الفرجة'
-);
+	'mediabox_slogan' => 'صندوق الفرجة',
+];
