@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=lt
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// B
 	'bouton_ajouter_document' => 'ĮTERPTI DOKUMENTĄ', # MODIF
@@ -36,5 +32,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 
 	// U
 	'upload_fichier_zip' => 'ZIP failas',
-	'upload_fichier_zip_texte2' => 'Gal būt šis failas'
-);
+	'upload_fichier_zip_texte2' => 'Gal būt šis failas',
+];
