@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-mots?lang_cible=en
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// M
 	'mots_description' => 'Keywords and keywords groups',
-	'mots_slogan' => 'Management of keywords and keywords groups in SPIP'
-);
+	'mots_slogan' => 'Management of keywords and keywords groups in SPIP',
+];
