@@ -32,6 +32,9 @@ function action_plan_dist() {
 		'lister' => ($objet == 'rubriques') ? 'rubrique' : 'tout',
 		'conteneur' => 'non'
 	];
+	if ($filtre_objet_enfant = _request('filtre_objet_enfant')) {
+		$env['filtre_objet_enfant'] = $filtre_objet_enfant;
+	}
 
 	if ($statut = _request('statut')) {
 		$env['statut'] = $statut;
