@@ -45,39 +45,42 @@ function optimiser_base_revisions() {
 	/**
 	 * On commence par récupérer la liste des types d'objet ayant au moins une révision
 	 */
-	$objets_revises = sql_select('objet', 'spip_versions', 'id_version=1', 'objet');
+	$objets_revises = sql_allfetsel('objet', 'spip_versions', 'id_version=1', 'objet');
+	$objets_revises = array_filter(array_column($objets_revises, 'objet'));
 
 	/**
 	 * Pour chaque objet, on va contruire un tableau des identifiants disparus
 	 * On supprimera ensuite les occurences dans spip_versions et spip_versions_fragments
 	 */
-	while ($objet = sql_fetch($objets_revises)) {
-		$in = [];
-		$table = table_objet_sql($objet['objet']);
-		$id_table_objet = id_table_objet($objet['objet']);
-		$res = sql_select(
-			'A.id_objet AS id_objet, A.objet AS objet',
-			"spip_versions AS A LEFT JOIN $table AS R
-				ON R.$id_table_objet=A.id_objet AND A.objet=" . sql_quote($objet['objet']),
-			"R.$id_table_objet IS NULL AND A.objet=" . sql_quote($objet['objet']) . ' AND A.id_objet > 0',
-			'A.id_objet',
-			'A.id_objet'
-		);
+	foreach ($objets_revises as $objet) {
+		$table = table_objet_sql($objet);
+		if (sql_table_exists($table)) {
+			$in = [];
+			$id_table_objet = id_table_objet($objet);
+			$res = sql_select(
+				'A.id_objet AS id_objet, A.objet AS objet',
+				"spip_versions AS A LEFT JOIN $table AS R
+					ON R.$id_table_objet=A.id_objet AND A.objet=" . sql_quote($objet),
+				"R.$id_table_objet IS NULL AND A.objet=" . sql_quote($objet) . ' AND A.id_objet > 0',
+				'A.id_objet',
+				'A.id_objet'
+			);
 
-		while ($row = sql_fetch($res)) {
-			$in[$row['id_objet']] = true;
-		}
-		sql_free($res);
+			while ($row = sql_fetch($res)) {
+				$in[$row['id_objet']] = true;
+			}
+			sql_free($res);
 
-		/**
-		 * Si on a un array
-		 * On supprime toute occurence des objets disparus dans :
-		 * -* spip_versions
-		 * -* spip_versions_fragments
-		 */
-		if ($in) {
-			foreach (['spip_versions', 'spip_versions_fragments'] as $table) {
-				sql_delete($table, sql_in('id_objet', array_keys($in)) . ' AND objet=' . sql_quote($objet['objet']));
+			/**
+			 * Si on a un array
+			 * On supprime toute occurence des objets disparus dans :
+			 * -* spip_versions
+			 * -* spip_versions_fragments
+			 */
+			if ($in) {
+				foreach (['spip_versions', 'spip_versions_fragments'] as $table) {
+					sql_delete($table, sql_in('id_objet', array_keys($in)) . ' AND objet=' . sql_quote($objet));
+				}
 			}
 		}
 	}
