@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/sites?lang_cible=de
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// A
 	'articles_dispo' => 'In der Warteschlange',
@@ -154,5 +150,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'tout_voir' => 'Alle syndizierten Artikel anzeigen',
 
 	// U
-	'un_article_syndic' => '1 syndizierter Artikel'
-);
+	'un_article_syndic' => '1 syndizierter Artikel',
+];
