@@ -3,16 +3,12 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/sites?lang_cible=is
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// E
 	'entree_description_site' => 'Lýsing á síðunni',
 
 	// I
 	'icone_modifier_site' => 'Breyta þessari heimasíðu',
-	'info_a_valider' => '[staðfesta]'
-);
+	'info_a_valider' => '[staðfesta]',
+];
