@@ -3,14 +3,10 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-stats?lang_cible=oc_ni_mis
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// S
 	'stats_description' => 'Estatìstica de SPIP',
 	'stats_nom' => 'Estatìstica',
-	'stats_slogan' => 'Gestioun dei estatìstica en SPIP'
-);
+	'stats_slogan' => 'Gestioun dei estatìstica en SPIP',
+];
