@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=el
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// B
 	'bouton_effacer_statistiques' => 'Delete the statistics', # MODIF
@@ -30,5 +26,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'onglet_repartition_lang' => 'Κατάταξη ανά γλώσσα',
 
 	// R
-	'resume' => 'Resume' # MODIF
-);
+	'resume' => 'Resume', # MODIF
+];
