@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=eo
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// A
 	'archiver' => 'Enarĥivigi',
@@ -15,8 +11,6 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'archiver_concatener_ignorer' => 'La vizitoj malpli ol @nb@-jaraj ne estas koncernataj.',
 	'archiver_concatener_par_an' => 'La vizitoj pli ol @nb@-jaraj estos kunmetitaj, por ĉiu artikolo je la unua tago de ĉiu jaro.',
 	'archiver_concatener_par_mois' => 'La vizitoj pli ol @nb@-jaraj estos kunmetitaj, por ĉiu artikolo je la unua tago de ĉiu monato.',
-	'archiver_conseil_sauvegarde' => 'Konsilindas savkopii unue la datumbazon.',
-	'archiver_description' => 'Tiu paĝo disponigas ilojn por purigi aŭ enarĥivigi la statistikojn de la retejo.',
 	'archiver_et_nettoyer' => 'Enarĥivigi kaj purigi',
 	'archiver_nettoyer' => 'Purigi',
 	'archiver_nettoyer_explications' => 'Forigas la liniojn pri referencantoj kaj vizitoj, kies artikoloj ne (plu) ekzistas en la datumbazo.',
@@ -24,7 +18,6 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'archiver_nettoyer_visites_articles' => 'Purigi la vizitojn de la artikoloj („visites_articles“)',
 	'archiver_nombre_lignes' => 'Nombro de linioj',
 	'archiver_operation_longue' => 'Tiu operacio povas longe daŭri, ĉefe la unuan fojon.',
-	'archiver_operations_irreversibles' => 'Tiuj operacioj estas neinversigeblaj !',
 
 	// B
 	'bouton_effacer_referers' => 'Forigi nur la enirintajn ligilojn',
@@ -75,5 +68,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 
 	// V
 	'visites_journalieres' => 'Taga vizitnombro',
-	'visites_mensuelles' => 'Monata vizitnombro'
-);
+	'visites_mensuelles' => 'Monata vizitnombro',
+];
