@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=pt
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// B
 	'bouton_effacer_referers' => 'Apagar apenas as ligações que são recebidas',
@@ -57,5 +53,5 @@ na classificação por popularidade, é indicado na margem ; a popularidade do
 	// V
 	'visites' => 'Visitas',
 	'visites_journalieres' => 'Número de visitas por dia',
-	'visites_mensuelles' => 'Número de visitas por mês'
-);
+	'visites_mensuelles' => 'Número de visitas por mês',
+];
