@@ -48,17 +48,17 @@ function action_actionner_dist() {
 		// l'action suivante.
 		include_spip('inc/config');
 		if (lire_config('svp/mode_pas_a_pas') == 'oui') {
-			include_spip('inc/minipres');
 			include_spip('inc/filtres');
 			$pres = $actionneur->presenter_actions();
-			$btn = "<a href='".attribut_html($url)."'>[ Action Suivante ]</a>";
-			$styles = "
-				<style type='text/css'>
-				#minipres #actionner .fail {color:#c30000;}
-				#minipres #actionner ul {margin-left: 0.5em;}
-				#minipres #actionner li {list-style-type:square; margin-left: 0.5em;}
-				</style>";
-			echo minipres(_T('svp:installation_en_cours'), $pres . '<br /><br />' . $btn . $styles);
+			$btn = "<a href='".attribut_html($url)."' class='btn btn-primary'>Action Suivante</a>";
+
+			$options = [
+				'titre' => _T('svp:installation_en_cours'),
+				'css_files' => [find_in_theme('minipage-svp.css')],
+				'footer' => $btn
+			];
+			$minipage = new Spip\Afficher\Minipage\Admin();
+			echo $minipage->page($pres, $options);
 			die();
 		}
 
@@ -115,29 +115,24 @@ function svp_redirige_boucle($url, $texte, $progres) {
 	}
 	@ob_implicit_flush(1);
 
+	$progress = round($progres * 100);
 	$pres = '<meta http-equiv="refresh" content="0;' . $url . '">';
 	$pres .= "
-			<div class='derniere_action'>$texte</div>
-			<div class='progression'>" . round($progres * 100) . "%</div>
-			<div class='bar'><div style='width:" . round($progres * 100) . "%'></div></div>
-			";
+		<div class='derniere_action'>$texte</div>
+		<div class='progression'>
+		<label for='progression_bar'>{$progress}%</label>
+		<progress id=\"progression_bar\" max=\"100\" value=\"{$progress}\"> {$progress}% </progress>
+		</div>
+		";
 
-	$styles = "
-		<style type='text/css'>
-		#minipres .derniere_action { font-weight:bold; }
-		#minipres div {
-			line-height:140%;
-		}
-		#minipres div.progression {
-			margin-top:2em;
-			font-weight:bold;
-			font-size:1.4em;
-			text-align:center;
-		}
-		#minipres .bar {border:1px solid #aaa;}
-		#minipres .bar div {background:#aaa;height:1em;}
-		</style>";
 
-	echo minipres(_T('svp:installation_en_cours'), $pres . $styles);
+
+	$options = [
+		'titre' => _T('svp:installation_en_cours'),
+		'css_files' => [find_in_theme('minipage-svp.css')],
+		'footer' => ''
+	];
+	$minipage = new Spip\Afficher\Minipage\Admin();
+	echo $minipage->page($pres, $options);
 	exit;
 }
