@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-svp?lang_cible=fr_fem
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// S
 	'svp_description' => 'Ce plugin fournit, d’une part,  une API permettant d’effectuer des recherches multi-critères, de collecter, et de présenter les informations sur les plugins SPIP (modules fonctionnels, thèmes et squelettes) et d’autre part, une nouvelle interface d’administration des plugins gérant les dépendances entre plugins.',
-	'svp_slogan' => 'SerVeur d’information et de téléchargement des Plugins'
-);
+	'svp_slogan' => 'SerVeur d’information et de téléchargement des Plugins',
+];
