@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-svp?lang_cible=ru
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// S
 	'svp_description' => 'Этот модуль предоставляет API и интерфейс для управления плагинами SPIP.',
-	'svp_slogan' => 'Управление плагинами'
-);
+	'svp_slogan' => 'Управление плагинами',
+];
