@@ -3,14 +3,10 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/334?lang_cible=en
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// R
 	'retour_ligne_auto' => 'Automatic word wrap',
 	'retour_ligne_ignore' => 'Ignore word wrap',
-	'retour_ligne_manuel' => 'Manual word wrap'
-);
+	'retour_ligne_manuel' => 'Manual word wrap',
+];
