@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/urls?lang_cible=en
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// A
 	'actualiser_toutes' => 'Update all urls',
@@ -71,5 +67,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 
 	// V
 	'verifier_url_nettoyee' => 'The URL has been corrected, you can check before saving.',
-	'verrouiller_url' => 'Lock'
-);
+	'verrouiller_url' => 'Lock',
+];
